==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/barcode/ObjectFactory.java <==

package net.webpdf.wsclient.schema.extraction.barcode;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.webpdf.wsclient.schema.extraction.barcode package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.webpdf.wsclient.schema.extraction.barcode
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BarcodesType }
     * 
     * @return
     *     the new instance of {@link BarcodesType }
     */
    public BarcodesType createBarcodesType() {
        return new BarcodesType();
    }

    /**
     * Create an instance of {@link BarcodeType }
     * 
     * @return
     *     the new instance of {@link BarcodeType }
     */
    public BarcodeType createBarcodeType() {
        return new BarcodeType();
    }

    /**
     * Create an instance of {@link RectangleType }
     * 
     * @return
     *     the new instance of {@link RectangleType }
     */
    public RectangleType createRectangleType() {
        return new RectangleType();
    }

    /**
     * Create an instance of {@link PositionedContentElementType }
     * 
     * @return
     *     the new instance of {@link PositionedContentElementType }
     */
    public PositionedContentElementType createPositionedContentElementType() {
        return new PositionedContentElementType();
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/barcode/ObjectFactory.java <==

package net.webpdf.wsclient.schema.extraction.barcode;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.webpdf.wsclient.schema.extraction.barcode package. 
 * <p>An ObjectFactory allows you to programmatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.webpdf.wsclient.schema.extraction.barcode
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BarcodesType }
     * 
     * @return
     *     the new instance of {@link BarcodesType }
     */
    public BarcodesType createBarcodesType() {
        return new BarcodesType();
    }

    /**
     * Create an instance of {@link BarcodeType }
     * 
     * @return
     *     the new instance of {@link BarcodeType }
     */
    public BarcodeType createBarcodeType() {
        return new BarcodeType();
    }

    /**
     * Create an instance of {@link RectangleType }
     * 
     * @return
     *     the new instance of {@link RectangleType }
     */
    public RectangleType createRectangleType() {
        return new RectangleType();
    }

    /**
     * Create an instance of {@link PositionedContentElementType }
     * 
     * @return
     *     the new instance of {@link PositionedContentElementType }
     */
    public PositionedContentElementType createPositionedContentElementType() {
        return new PositionedContentElementType();
    }

}
